@@ -31,8 +31,10 @@ def load_obj(
     skip_materials: bool = False,
     maintain_order: bool = False,
     metadata: Optional[Dict] = None,
+    split_objects: bool = False,
+    split_groups: bool = False,
     **kwargs,
-):
+) -> Dict:
     """
     Load a Wavefront OBJ file into kwargs for a trimesh.Scene
     object.
@@ -47,11 +49,20 @@ def load_obj(
     group_material : bool
       Group faces that share the same material
       into the same mesh.
-    skip_materials : bool
+    skip_materials
       Don't load any materials.
-    maintain_order : bool or None
-      Do not reorder faces or vertices which may result
-      in visual artifacts.
+    maintain_order
+      Make the strongest attempt possible to not reorder faces
+      or vertices which may result in visual artifacts and other
+      odd behavior. The OBJ data structure is quite different than
+      the "flat matching array" used by Trimesh and GLTF so this may
+      not be completely possible.
+    split_objects
+      Whenever the loader encounters an `o` directive in the OBJ
+      file, split the loaded result into a new Trimesh object.
+    split_groups
+        Whenever the loader encounters a `g` directive in the OBJ
+        file, split the loaded result into a new Trimesh object.
 
     Returns
     -------------
@@ -96,13 +107,13 @@ def load_obj(
 
     # get relevant chunks that have face data
     # in the form of (material, object, chunk)
-    face_tuples = _preprocess_faces(text=text)
+    face_tuples = _preprocess_faces(text, split_objects, split_groups)
 
     # combine chunks that have the same material
     # some meshes end up with a LOT of components
     # and will be much slower if you don't do this
-    if group_material:
-        face_tuples = _group_by_material(face_tuples)
+    if group_material or split_objects or split_groups:
+        face_tuples = _group_by(face_tuples, group_material, split_objects, split_groups)
 
     # no faces but points given
     # return point cloud
@@ -121,7 +132,7 @@ def load_obj(
     geometry = {}
     while len(face_tuples) > 0:
         # consume the next chunk of text
-        material, current_object, chunk = face_tuples.pop()
+        material, current_object, current_group, chunk = face_tuples.pop()
         # do wangling in string form
         # we need to only take the face line before a newline
         # using builtin functions in a list comprehension
@@ -167,8 +178,18 @@ def load_obj(
             log.debug("faces have mixed data: using slow fallback!")
             faces, faces_tex, faces_norm = _parse_faces_fallback(face_lines)
 
-        if group_material and len(materials) > 1:
-            name = material
+        # build name from components
+        name_parts = []
+        if split_objects and current_object is not None:
+            name_parts.append(current_object)
+        if split_groups and current_group is not None:
+            name_parts.append(current_group)
+        if group_material and len(materials) > 1 and material is not None:
+            name_parts.append(str(material))
+
+        # join parts or fall back to defaults
+        if name_parts:
+            name = "_".join(name_parts)
         elif current_object is not None:
             name = current_object
         else:
@@ -184,7 +205,7 @@ def load_obj(
                 if i is not None
             )
 
-        # ensure the name is always unique
+        # ensure the name is always unique in the geometry dict
         name = util.unique_name(name, geometry)
 
         # try to get usable texture
@@ -648,7 +669,7 @@ def _parse_vertices(text):
     return v, vn, vt, vc
 
 
-def _group_by_material(face_tuples):
+def _group_by(face_tuples, use_mtl: bool, use_obj: bool, use_group: bool):
     """
     For chunks of faces split by material group
     the chunks that share the same material.
@@ -657,35 +678,48 @@ def _group_by_material(face_tuples):
     ------------
     face_tuples : (n,) list of (material, obj, chunk)
       The data containing faces
+    use_mtl
+      Group tuples by `usemtl` commands
+    use_obj
+      Group tuples by `o` commands
+    use_group
+      Group tuples by `g` commands
 
     Returns
     ------------
-    grouped : (m,) list of (material, obj, chunk)
-      Grouped by material
+    grouped : (m,) list of tuples containing:
+              `(material name, objectname, group name, raw chunk)`
     """
 
     # store the chunks grouped by material
-    grouped = defaultdict(lambda: ["", "", []])
+    grouped = defaultdict(lambda: ["", "", "", []])
     # loop through existring
-    for material, obj, chunk in face_tuples:
-        grouped[material][0] = material
-        grouped[material][1] = obj
+    for material, obj, group, chunk in face_tuples:
+        # tuple key for the dict
+        key = (
+            material if use_mtl else None,
+            obj if use_obj else None,
+            group if use_group else None,
+        )
+        grouped[key][0] = material
+        grouped[key][1] = obj
+        grouped[key][2] = group
         # don't do a million string concatenations in loop
-        grouped[material][2].append(chunk)
+        grouped[key][3].append(chunk)
     # go back and do a join to make a single string
-    for k in grouped.keys():
-        grouped[k][2] = "\n".join(grouped[k][2])
+    for key in grouped.keys():
+        grouped[key][3] = "\n".join(grouped[key][3])
     # return as list
     return list(grouped.values())
 
 
-def _preprocess_faces(text):
+def _preprocess_faces(text, use_obj=False, use_groups=False):
     """
     Pre-Process Face Text
 
     Rather than looking at each line in a loop we're
     going to split lines by directives which indicate
-    a new mesh, specifically 'usemtl' and 'o' keys
+    a new mesh, specifically 'usemtl', 'o', and 'g' keys
     search for materials, objects, faces, or groups
 
     Parameters
@@ -731,15 +765,27 @@ def _preprocess_faces(text):
     # find the index of every material change
     idx_mtl = np.array([m.start(0) for m in re.finditer("usemtl ", f_chunk)], dtype=int)
     # find the index of every new object
-    idx_obj = np.array([m.start(0) for m in re.finditer("\no ", f_chunk)], dtype=int)
+    split_idxs = [[0, len(f_chunk)], idx_mtl]
+
+    # NOTE: This used to split objects on every run, but now it does not
+    if use_obj:
+        split_idxs.append(
+            np.array([m.start(0) for m in re.finditer("\no ", f_chunk)], dtype=int)
+        )
+
+    if use_groups:
+        split_idxs.append(
+            np.array([m.start(0) for m in re.finditer("\ng ", f_chunk)], dtype=int)
+        )
 
     # find all the indexes where we want to split
-    splits = np.unique(np.concatenate(([0, len(f_chunk)], idx_mtl, idx_obj)))
+    splits = np.unique(np.concatenate(tuple(split_idxs)))
 
     # track the current material and object ID
     current_obj = None
     current_mtl = None
-    # store (material, object, face lines)
+    current_group = None
+    # store (material, object, group, face lines)
     face_tuples = []
 
     for start, end in zip(splits[:-1], splits[1:]):
@@ -753,11 +799,12 @@ def _preprocess_faces(text):
             current_mtl = current_mtl[6:].strip()
         # Discard the g tag line in the list of faces
         elif chunk.startswith("g "):
-            _, chunk = chunk.split("\n", 1)
+            current_group, chunk = chunk.split("\n", 1)
+            current_group = current_group[2:].strip()
         # If we have an f at the beginning of a line
         # then add it to the list of faces chunks
         if chunk.startswith("f ") or "\nf" in chunk:
-            face_tuples.append((current_mtl, current_obj, chunk))
+            face_tuples.append((current_mtl, current_obj, current_group, chunk))
     return face_tuples
 
 
